# Standard Library
import shutil

# Third Party
from invoke import task

# NOTE: Invoke tasks files don't support mypy typechecking for the forseeable future
# They were looking at addressing it after Python2 EOL 01-01-2020 but there was a global pandemic.
# https://github.com/pyinvoke/invoke/issues/357


@task
def format(c):
    """Autoformat code for code style."""
    c.run("black .")
    c.run("isort .")


@task
def lint(c):
    """Linting and style checking."""
    c.run("black --check .")
    c.run("isort --check .")
    c.run("flake8 .")


@task
def typecheck(c):
    """Run typechecking tooling."""
    c.run("mypy .")


@task
def test(c):
    """Run test suite."""
    c.run("python3 -m pytest")


@task
def build(c):
    """Build wheel."""
    shutil.rmtree("dist/")
    c.run("poetry build -f wheel")


@task(pre=[lint, typecheck, test])
def ci(c):
    """Run linting and test suite for Continuous Integration."""
    ...
